==> s2i-annotations-2.11.3-sources.jar: io/dekorate/s2i/config/S2iBuildConfigBuilder.java <==
package io.dekorate.s2i.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class S2iBuildConfigBuilder extends S2iBuildConfigFluentImpl<S2iBuildConfigBuilder> implements VisitableBuilder<io.dekorate.s2i.config.S2iBuildConfig,io.dekorate.s2i.config.S2iBuildConfigBuilder>{
  public S2iBuildConfigBuilder() {
    this(false);
  }
  public S2iBuildConfigBuilder(Boolean validationEnabled) {
    this(new S2iBuildConfig(), validationEnabled);
  }
  public S2iBuildConfigBuilder(S2iBuildConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public S2iBuildConfigBuilder(io.dekorate.s2i.config.S2iBuildConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new S2iBuildConfig(), validationEnabled);
  }
  public S2iBuildConfigBuilder(io.dekorate.s2i.config.S2iBuildConfigFluent<?> fluent,io.dekorate.s2i.config.S2iBuildConfig instance) {
    this(fluent, instance, false);
  }
  public S2iBuildConfigBuilder(io.dekorate.s2i.config.S2iBuildConfigFluent<?> fluent,io.dekorate.s2i.config.S2iBuildConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProject(instance.getProject()); 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withEnabled(instance.getEnabled()); 
    fluent.withRegistry(instance.getRegistry()); 
    fluent.withGroup(instance.getGroup()); 
    fluent.withName(instance.getName()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withImage(instance.getImage()); 
    fluent.withDockerFile(instance.getDockerFile()); 
    fluent.withAutoBuildEnabled(instance.getAutoBuildEnabled()); 
    fluent.withAutoPushEnabled(instance.getAutoPushEnabled()); 
    fluent.withAutoLoadEnabled(instance.isAutoLoadEnabled()); 
    fluent.withBuilderImage(instance.getBuilderImage()); 
    fluent.withBuildEnvVars(instance.getBuildEnvVars()); 
    fluent.withAutoDeployEnabled(instance.getAutoDeployEnabled()); 
    this.validationEnabled = validationEnabled; 
  }
  public S2iBuildConfigBuilder(io.dekorate.s2i.config.S2iBuildConfig instance) {
    this(instance,false);
  }
  public S2iBuildConfigBuilder(io.dekorate.s2i.config.S2iBuildConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withEnabled(instance.getEnabled()); 
    this.withRegistry(instance.getRegistry()); 
    this.withGroup(instance.getGroup()); 
    this.withName(instance.getName()); 
    this.withVersion(instance.getVersion()); 
    this.withImage(instance.getImage()); 
    this.withDockerFile(instance.getDockerFile()); 
    this.withAutoBuildEnabled(instance.getAutoBuildEnabled()); 
    this.withAutoPushEnabled(instance.getAutoPushEnabled()); 
    this.withAutoLoadEnabled(instance.isAutoLoadEnabled()); 
    this.withBuilderImage(instance.getBuilderImage()); 
    this.withBuildEnvVars(instance.getBuildEnvVars()); 
    this.withAutoDeployEnabled(instance.getAutoDeployEnabled()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.s2i.config.S2iBuildConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public EditableS2iBuildConfig build() {
    EditableS2iBuildConfig buildable = new EditableS2iBuildConfig(fluent.getProject(),fluent.getAttributes(),fluent.getEnabled(),fluent.getRegistry(),fluent.getGroup(),fluent.getName(),fluent.getVersion(),fluent.getImage(),fluent.getDockerFile(),fluent.getAutoBuildEnabled(),fluent.getAutoPushEnabled(),fluent.getAutoLoadEnabled(),fluent.getBuilderImage(),fluent.getBuildEnvVars(),fluent.getAutoDeployEnabled());
    return buildable;
  }
  
}

==> s2i-annotations-3.0.2-sources.jar: io/dekorate/s2i/config/S2iBuildConfigBuilder.java <==
package io.dekorate.s2i.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class S2iBuildConfigBuilder extends S2iBuildConfigFluentImpl<S2iBuildConfigBuilder> implements VisitableBuilder<S2iBuildConfig,S2iBuildConfigBuilder>{
  public S2iBuildConfigBuilder() {
    this(false);
  }
  public S2iBuildConfigBuilder(Boolean validationEnabled) {
    this(new S2iBuildConfig(), validationEnabled);
  }
  public S2iBuildConfigBuilder(S2iBuildConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public S2iBuildConfigBuilder(S2iBuildConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new S2iBuildConfig(), validationEnabled);
  }
  public S2iBuildConfigBuilder(S2iBuildConfigFluent<?> fluent,S2iBuildConfig instance) {
    this(fluent, instance, false);
  }
  public S2iBuildConfigBuilder(S2iBuildConfigFluent<?> fluent,S2iBuildConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProject(instance.getProject()); 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withEnabled(instance.getEnabled()); 
    fluent.withRegistry(instance.getRegistry()); 
    fluent.withGroup(instance.getGroup()); 
    fluent.withName(instance.getName()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withImage(instance.getImage()); 
    fluent.withDockerFile(instance.getDockerFile()); 
    fluent.withAutoBuildEnabled(instance.getAutoBuildEnabled()); 
    fluent.withAutoPushEnabled(instance.getAutoPushEnabled()); 
    fluent.withAutoLoadEnabled(instance.isAutoLoadEnabled()); 
    fluent.withBuilderImage(instance.getBuilderImage()); 
    fluent.withBuildEnvVars(instance.getBuildEnvVars()); 
    fluent.withAutoDeployEnabled(instance.getAutoDeployEnabled()); 
    this.validationEnabled = validationEnabled; 
  }
  public S2iBuildConfigBuilder(S2iBuildConfig instance) {
    this(instance,false);
  }
  public S2iBuildConfigBuilder(S2iBuildConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withEnabled(instance.getEnabled()); 
    this.withRegistry(instance.getRegistry()); 
    this.withGroup(instance.getGroup()); 
    this.withName(instance.getName()); 
    this.withVersion(instance.getVersion()); 
    this.withImage(instance.getImage()); 
    this.withDockerFile(instance.getDockerFile()); 
    this.withAutoBuildEnabled(instance.getAutoBuildEnabled()); 
    this.withAutoPushEnabled(instance.getAutoPushEnabled()); 
    this.withAutoLoadEnabled(instance.isAutoLoadEnabled()); 
    this.withBuilderImage(instance.getBuilderImage()); 
    this.withBuildEnvVars(instance.getBuildEnvVars()); 
    this.withAutoDeployEnabled(instance.getAutoDeployEnabled()); 
    this.validationEnabled = validationEnabled; 
  }
  S2iBuildConfigFluent<?> fluent;
  Boolean validationEnabled;
  public EditableS2iBuildConfig build() {
    EditableS2iBuildConfig buildable = new EditableS2iBuildConfig(fluent.getProject(),fluent.getAttributes(),fluent.getEnabled(),fluent.getRegistry(),fluent.getGroup(),fluent.getName(),fluent.getVersion(),fluent.getImage(),fluent.getDockerFile(),fluent.getAutoBuildEnabled(),fluent.getAutoPushEnabled(),fluent.getAutoLoadEnabled(),fluent.getBuilderImage(),fluent.getBuildEnvVars(),fluent.getAutoDeployEnabled());
    buildable.setPartOf(fluent.getPartOf());
    return buildable;
  }
  
}
